@@ -44,21 +44,21 @@
 #' )
 #' }
 #' @export
-bucket_trades <- function(
-  binSize = "1m",
-  partial = "false",
-  symbol = "XBTUSD",
-  count = 1000,
-  reverse = "true",
-  filter = NULL,
-  columns = NULL,
-  start = NULL,
-  startTime = NULL,
-  endTime = NULL,
-  use_auth = FALSE
-) {
+bucket_trades <- function(binSize = "1m",
+                          partial = "false",
+                          symbol = "XBTUSD",
+                          count = 1000,
+                          reverse = "true",
+                          filter = NULL,
+                          columns = NULL,
+                          start = NULL,
+                          startTime = NULL,
+                          endTime = NULL,
+                          use_auth = FALSE) {
   check_internet()
 
+  as <- available_symbols()
+
   stop_if_not(
     symbol %in% as,
     msg = paste(
@@ -196,21 +196,21 @@ bucket_trades <- function(
 #' )
 #' }
 #' @export
-tn_bucket_trades <- function(
-  binSize = "1m",
-  partial = "false",
-  symbol = "XBTUSD",
-  count = 1000,
-  reverse = "true",
-  filter = NULL,
-  columns = NULL,
-  start = NULL,
-  startTime = NULL,
-  endTime = NULL,
-  use_auth = FALSE
-) {
+tn_bucket_trades <- function(binSize = "1m",
+                             partial = "false",
+                             symbol = "XBTUSD",
+                             count = 1000,
+                             reverse = "true",
+                             filter = NULL,
+                             columns = NULL,
+                             start = NULL,
+                             startTime = NULL,
+                             endTime = NULL,
+                             use_auth = FALSE) {
   check_internet()
 
+  as <- available_symbols()
+
   stop_if_not(
     symbol %in% as,
     msg = paste(
@@ -324,4 +324,4 @@ tn_bucket_trades <- function(
   )
 
   return(result)
-}
+}
\ No newline at end of file
